@@ -6,10 +6,10 @@ use Role::Tiny;
 use Alien::Install::Util;
 
 # ABSTRACT: Test compile alien role
-our $VERSION = '0.08_05'; # VERSION
+our $VERSION = '0.08_06'; # VERSION
 
 requires 'error';
-requires '_config_test_compile_run_program';
+requires 'alien_config_test_compile_run_program';
 
 register_build_requires  'ExtUtils::CBuilder' => 0;
 register_system_requires 'ExtUtils::CBuilder' => 0;
@@ -29,7 +29,7 @@ sub test_compile_run
   
   my $dir = $opt{dir} || do { require File::Temp; File::Temp::tempdir( CLEANUP => 1 ) };
   my $fn = catfile($dir, 'test.c');
-  spew $fn, $self->_config_test_compile_run_program;
+  spew $fn, $self->alien_config_test_compile_run_program;
   
   
   my $exe = eval {
@@ -75,7 +75,7 @@ sub test_compile_run
     $self->{error} = "child exited with value " . ($? >> 8);
   }
   
-  my $match = $self->can('_config_test_compile_run_match') ? $self->_config_test_compile_run_match : qr{version = '(.*?)'};
+  my $match = $self->can('alien_config_test_compile_run_match') ? $self->alien_config_test_compile_run_match : qr{version = '(.*?)'};
   
   if($output =~ $match)
   {
@@ -102,7 +102,7 @@ Alien::Install::Role::TestCompileRun - Test compile alien role
 
 =head1 VERSION
 
-version 0.08_05
+version 0.08_06
 
 =head1 AUTHOR
 
