@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Installer for LZO
-our $VERSION = '0.08_05'; # VERSION
+our $VERSION = '0.08_06'; # VERSION
 
 sub _catfile {
   my $path = File::Spec->catfile(@_);
@@ -479,7 +479,7 @@ Alien::LZO::Installer - Installer for LZO
 
 =head1 VERSION
 
-version 0.08_05
+version 0.08_06
 
 =head1 SYNOPSIS
 
@@ -494,8 +494,8 @@ Build.PL
  my $installer = eval { Alien::LZO::Installer->system_install };
  if($installer)
  {
-   $build_args{extra_compiler_flags} = $installer->cflags,
-   $build_args{extra_linker_flags}   = $installer->libs,
+   $build_args{extra_compiler_flags} = $installer->cflags;
+   $build_args{extra_linker_flags}   = $installer->libs;
  }
  
  my $build = Module::Build->new(%build_args);
